PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/quad_check.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Namespaces | Variables
quad_check.py File Reference

## Namespaces
| pawpyseed.core.quad_check

## Variables
int | pawpyseed.core.quad_check.total = 0
int | pawpyseed.core.quad_check.numtheta = min( int(rstep*27/100), 26 )+3
| pawpyseed.core.quad_check.pts
| pawpyseed.core.quad_check.wts
| pawpyseed.core.quad_check.numphi = int((numtheta*2+2) * (1-pts[thetastep]**2)**0.5)